RuntimeLeaseConfig

Struct RuntimeLeaseConfig 

pub struct RuntimeLeaseConfig {
    pub lease_id: String,
    pub owner_id: String,
    pub ttl: Duration,
    pub renew_interval: Duration,
    pub standby_retry_interval: Duration,
}
Runtime lease settings for one singleton worker group.

Fields

lease_id: String

Stable lease key shared by all service instances.

owner_id: String

Process-unique identifier for the current runtime owner.

ttl: Duration

Time after which another owner may take over if renewals stop.

renew_interval: Duration

Interval used by the current owner to renew the lease.

standby_retry_interval: Duration

Interval used by standby instances before attempting acquisition again.

Implementations

Source

impl RuntimeLeaseConfig

pub fn new(lease_id: impl Into<String>, owner_id: impl Into<String>) -> Self

Creates runtime lease settings with conservative default intervals.

pub const fn ttl(self, ttl: Duration) -> Self

Sets the lease TTL.

pub const fn renew_interval(self, renew_interval: Duration) -> Self

Sets the owner renewal interval.

pub const fn standby_retry_interval( self, standby_retry_interval: Duration, ) -> Self

Sets the standby acquisition retry interval.