AsterRuntimeBuilder

Struct AsterRuntimeBuilder 

pub struct AsterRuntimeBuilder<S = ()> { /* private fields */ }
Builder for AsterRuntime.

Implementations

Source

impl<S> AsterRuntimeBuilder<S>

pub fn shutdown_token(&self) -> &CancellationToken

Returns the runtime-owned shutdown token.

This accessor is primarily for shared component crates that implement AsterRuntimeComponent and need to spawn work using the same token the runtime cancels when the process receives a termination signal.

pub fn component<C>(self, component: C) -> C::Output

Adds one runtime component.

pub fn before_shutdown<F, Fut>(self, before_shutdown: F) -> Self
where F: FnOnce() -> Fut + Send + 'static, Fut: Future<Output = ()> + Send + 'static,

Registers a product hook that runs after the service future stops and before components.

pub fn build(self) -> Result<AsterRuntime<S>, AsterRuntimeError>

Builds the runtime runner.

Source

impl<S> AsterRuntimeBuilder<S>
where S: Future,

pub async fn run(self) -> Result<S::Output, AsterRuntimeError>

Builds and runs the runtime.