wait_for_termination_signal

Function wait_for_termination_signal 

pub async fn wait_for_termination_signal() -> Result<TerminationSignal, RuntimeSignalError>
Waits until the process receives a termination signal.

Errors

Returns an error when the platform signal listeners cannot be installed or all listener streams terminate before delivering a signal.