run_optional_startup_phase

Function run_optional_startup_phase 

pub async fn run_optional_startup_phase<F, Fut, E>(
    name: &'static str,
    phase: F,
) -> StartupPhaseReport
where F: FnOnce() -> Fut, Fut: Future<Output = Result<(), E>>, E: Display,
Runs one optional startup phase and returns its report.

Optional phase failures are logged and represented as StartupPhaseStatus::SkippedAfterFailure, but the error does not abort startup.